<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:include href="BasicAttributes.xsl"/>

<xsl:template match="/">
	<html>
		<xsl:call-template name="LinkStyle" /> 
	    <xsl:call-template name="FontStyle" /> 
		
		<body>
			<span class="Text">
			<xsl:apply-templates/>	
			</span>
		</body>
		
	</html>
</xsl:template>

<xsl:template match="categorypath">
	<tr><td>
	<span class="SubHeader">問題種類</span>
	</td></tr>
	<tr><td>
	<span class="Text">
	<xsl:apply-templates/>	
	</span>
	<p/>
	</td></tr>
</xsl:template>

<xsl:template match=" categorypath / category">
	<xsl:value-of select="."/> :
</xsl:template>

<xsl:template match=" categorypath / category[ last() ]">
	<xsl:value-of select="."/> 
</xsl:template>

<xsl:template match="name">
	<tr><td>
	<span class="SubHeader">問題名稱</span>
	</td></tr>
	<tr><td>
	<span class="Text">
		<xsl:apply-templates/>	
	</span>
	<br/>
	<p/>
	</td></tr>
</xsl:template>

<xsl:template match="title">
	<tr><td>
	<span class="SubHeader">
		<xsl:apply-templates/>	
	</span>
	</td></tr>
</xsl:template>

<xsl:template match="method">
	<span class="Code">
		<xsl:text> </xsl:text>
		<xsl:if test="@class">
			<span class="JavaType">
				<xsl:value-of select="@class"/>
			</span>
			<xsl:text>.</xsl:text>
		</xsl:if>
		<xsl:value-of select="@name"/>
		(<xsl:apply-templates select="param"/>)
		<xsl:text> </xsl:text>
	</span>	
</xsl:template>

<xsl:template match="method / param">
	<span class="JavaType"><xsl:value-of select="@type"/></span>, 
</xsl:template>

<xsl:template match="method / param[ last() ]">
	<span class="JavaType"><xsl:value-of select="@type"/></span>
</xsl:template>

<xsl:template match="severity">
	<tr><td>
	<span class="SubHeader">嚴重性</span>
	</td></tr>
	<tr><td>
	<span class="Text">
	 <xsl:value-of select="."/>
	 </span>
	 <p/>
	</td></tr>
</xsl:template>

<xsl:template match="jdk">
	<tr><td>
	<span class="SubHeader">JDK</span>
	</td></tr>
	<tr><td>
	<span class="Text">
	<xsl:text>問題位置：</xsl:text><xsl:value-of select="@problem"/>
	<xsl:if test="@fixed">
		<xsl:text>，已修正於 </xsl:text><xsl:value-of select="@fixed"/>
	</xsl:if>
	 </span>
	 <p/>
	</td></tr>
</xsl:template>

<xsl:template match="description">
	<tr><td>
	<span class="SubHeader">說明</span>
	</td></tr>
	<tr><td>
	<span class="Text">
		<xsl:apply-templates/>	
	</span>
	<p/>
	</td></tr>
</xsl:template>

<xsl:template match="line">
	<xsl:apply-templates/>		
	<br/>
</xsl:template>

<xsl:template match="codeline">
	<xsl:if test="@number">
		<xsl:text>    </xsl:text><xsl:value-of select="@number"/>:<xsl:text> </xsl:text>
	</xsl:if>
	<xsl:apply-templates/>		
	<br/>
</xsl:template>


<xsl:template match="list">
	<ul type="square">
		<xsl:apply-templates select="item"/>
	</ul>	
</xsl:template>

<xsl:template match="olist">
	<ol>
		<xsl:apply-templates select="item"/>
	</ol>	
</xsl:template>

<xsl:template match="item">
	<li>
		<xsl:apply-templates/>
	</li>	
</xsl:template>

<xsl:template match="em">
	<span class="Strong">
		<xsl:apply-templates/>
	</span>
</xsl:template>

<xsl:template match="example">
	<tr><td>
		<xsl:apply-templates/>
	</td></tr>
</xsl:template>

<xsl:template match="code">
	<table border="1" bgcolor="#F7F8F9">
		<tr><td>
			<span class="Text">
			<xsl:apply-templates/>	
			</span>
		</td></tr>
  	</table>
</xsl:template>

<xsl:template match="codesnippet">
	<table border="0" bgcolor="#F7F8F9">
		<tr><td>
			<span class="Text">
			<xsl:apply-templates/>	
			</span>
		</td></tr>
  	</table>
</xsl:template>

<xsl:template match="keyword">
	<span class="JavaKeyword"><xsl:apply-templates/></span>
</xsl:template>

<xsl:template match="type">
	<span class="JavaType"><xsl:apply-templates/></span>
</xsl:template>

<xsl:template match="comment">
	<span class="JavaComment"><xsl:apply-templates/></span>
</xsl:template>

<xsl:template match="const">
	<span class="JavaConst"><xsl:apply-templates/></span>
</xsl:template>

<xsl:template match="output">
	<span class="Strong">
		<p/><u>輸出</u><br/> 
	</span>
	<span class="Text">
		<xsl:apply-templates/><br/>
	</span>
</xsl:template>

<xsl:template match="expectedoutput">
	<span class="Strong">
		<p/><u>預期輸出</u><br/> 
	</span>
	<span class="Text">
		<xsl:apply-templates/><br/>
	</span>
</xsl:template>


<xsl:template match="space">
	<xsl:text> </xsl:text>
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="dquote">
	<xsl:text>&quot;</xsl:text>
	<xsl:apply-templates/>
	<xsl:text>&quot;</xsl:text>
</xsl:template>

<!-- Tab template was moved to basic attrributes 
     because of the problem with &nbsp; -->
     
<xsl:template match="note">
	<span class="Strong">
		<p/><u>附註：</u><br/> 
	</span>
	<span class="Text">
		<xsl:apply-templates/><br/>
	</span>
</xsl:template>


<xsl:template match="solution">
	<tr><td>
		<span class="SubHeader">解決方案</span>	
	</td></tr>
	<tr><td>
	<span class="Text">
		<xsl:apply-templates/>
	</span>
	</td></tr>
</xsl:template>

<xsl:template match="link">
	<a href="{@url}"><xsl:value-of select="@name"/></a>
</xsl:template>

<xsl:template match="refactoringname"/>

<xsl:template match="book">
	<span class="Italic">
	<xsl:apply-templates/>
	</span>
</xsl:template>

</xsl:stylesheet>
